@@ -1,20 +1,23 @@
-from .backported import getcallargs, getfullargspec
-from .docstring_parsing import Arg, DocStringInfo
-from .enabling import all_disabled
-from .interface import (CannotDecorateClassmethods, Contract, ContractException, 
-    ContractNotRespected, ContractSyntaxError, MissingContract, Where, 
-    describe_value)
-from .library import (CheckCallable, Extension, SeparateContext, 
-    identifier_expression)
-from .library.extensions import CheckCallableWithSelf
-from .syntax import ParseException, ParseFatalException, contract_expression
 import inspect
 import sys
 import types
 
+from .backported import getcallargs, getfullargspec
+from .docstring_parsing import Arg, DocStringInfo
+from .enabling import all_disabled
+from .interface import (CannotDecorateClassmethods, Contract,
+                        ContractException,
+                        ContractNotRespected, ContractSyntaxError,
+                        MissingContract, Where,
+                        describe_value)
+from .library import (CheckCallable, Extension, SeparateContext,
+                      identifier_expression)
+from .library.extensions import CheckCallableWithSelf
+from .syntax import ParseException, ParseFatalException, contract_expression
+
 
 def check_contracts(contracts, values, context_variables=None):
-    '''
+    """
         Checks that the values respect the contract.
         Not a public function -- no friendly messages.
 
@@ -33,7 +36,7 @@ def check_contracts(contracts, values, context_variables=None):
         :raise: ContractSyntaxError
         :raise: ContractNotRespected
         :raise: ValueError
-    '''
+    """
     assert isinstance(contracts, list)
     assert isinstance(contracts, list)
     assert len(contracts) == len(values)
@@ -62,13 +65,14 @@ def check_contracts(contracts, values, context_variables=None):
 class Storage:
     string2contract = {}
 
+
 def parse_contract_string(string):
     assert isinstance(string, str), type(string)
     if string in Storage.string2contract:
         return Storage.string2contract[string]
     try:
         c = contract_expression.parseString(string,
-                                             parseAll=True)[0]
+                                            parseAll=True)[0]
         assert isinstance(c, Contract), 'Want Contract, not %r' % c
         Storage.string2contract[string] = c
         return c
@@ -81,78 +85,38 @@ def parse_contract_string(string):
         msg = '%s' % e
         raise ContractSyntaxError(msg, where=where)
 
+
 # TODO: add decorator-specific exception
 
 
 def contract_decorator(*arg, **kwargs):
-    ''' 
+    """
         Decorator for adding contracts to functions.
-    
-        It is smart enough to support functions with variable number of 
+
+        It is smart enough to support functions with variable number of
         arguments and keyword arguments.
-        
+
         There are three ways to specify the contracts. In order of precedence:
-        
+
         - As arguments to this decorator. For example: ::
-        
+
               @contract(a='int,>0',b='list[N],N>0',returns='list[N]')
               def my_function(a, b):
                   # ...
                   pass
-        
+
         - As annotations (supported only in Python 3): ::
-        
+
               @contract
-              def my_function(a:'int,>0', b:'list[N],N>0') -> 'list[N]': 
+              def my_function(a:'int,>0', b:'list[N],N>0') -> 'list[N]':
                   # ...
                   pass
-        
+
         - Using ``:type:`` and ``:rtype:`` tags in the function's docstring: ::
-        
+
               @contract
-              def my_function(a, b): 
-                  """ Function description.
-                      :type a: int,>0
-                      :type b: list[N],N>0
-                      :rtype: list[N]
+              def my_function(a, b):
                   """
-                  pass
-        
-        **Signature and docstrings**: The signature of the decorated
-        function is conserved. By default, the docstring is modified
-        by adding ``:type:`` and ``:rtype:`` definitions. To avoid that,
-        pass ``modify_docstring=False`` as a parameter.
-        
-                 
-        **Contracts evaluation**: Note that all contracts for the arguments 
-        and the return values
-        are evaluated in the same context. This make it possible to use
-        common variables in the contract expression. For example, in the 
-        example above, the return value is constrained to be a list of the same 
-        length (``N``) as the parameter ``b``. 
-        
-        **Using docstrings** Note that, by convention, those annotations must 
-        be parseable as RestructuredText. This is relevant if you are using 
-        Sphinx.
-        If the contract string has special RST characters in it, like ``*``,
-        you can include it in double ticks. |pycontracts| will remove
-        the double ticks before interpreting the string.
-          
-        For example, the two annotations in this docstring are equivalent
-        for |pycontracts|, but the latter is better for Sphinx: ::
-           
-              """ My function 
-              
-                  :param a: First parameter
-                  :type a: list(tuple(str,*))
-                  
-                  :param b: First parameter
-                  :type b: ``list(tuple(str,*))``
-              """
-    
-        :raise: ContractException, if arguments are not coherent 
-        :raise: ContractSyntaxError
-    '''
     # OK, this is black magic. You are not expected to understand this.
     if arg:
         if isinstance(arg[0], types.FunctionType):
@@ -162,22 +126,22 @@ def contract_decorator(*arg, **kwargs):
                 return function
             try:
                 return contracts_decorate(function, **kwargs)
-            except ContractSyntaxError as e:
+            except ContractSyntaxError as es:
                 # Erase the stack
-                raise ContractSyntaxError(e.error, e.where)
+                raise ContractSyntaxError(es.error, es.where)
         else:
             msg = ('I expect that contracts() is called with '
-                    'only keyword arguments (passed: %r)' % arg)
+                   'only keyword arguments (passed: %r)' % arg)
             raise ContractException(msg)
     else:
         # We were called *with* parameters.
         if all_disabled():
-            def tmp_wrap(function):
-                return function
+            def tmp_wrap(f):
+                return f
         else:
-            def tmp_wrap(function):
+            def tmp_wrap(f):
                 try:
-                    return contracts_decorate(function, **kwargs)
+                    return contracts_decorate(f, **kwargs)
                 except ContractSyntaxError as e:
                     # Erase the stack
                     raise ContractSyntaxError(e.error, e.where)
@@ -185,14 +149,15 @@ def contract_decorator(*arg, **kwargs):
 
 
 def contracts_decorate(function_, modify_docstring=True, **kwargs):
-    ''' An explicit way to decorate a given function.
-        The decorator :py:func:`decorate` calls this function internally. 
-    '''
-    
+    """ An explicit way to decorate a given function.
+        The decorator :py:func:`decorate` calls this function internally.
+    """
+
     if isinstance(function_, classmethod):
         msg = """
 The function is a classmethod; PyContracts cannot decorate a classmethod. 
-You can, however, first decorate a function and then turn it into a classmethod.
+You can, however, first decorate a function and then turn it into a
+classmethod.
 
 For example, instead of doing this:
 
@@ -213,7 +178,6 @@ you can achieve the same goal by inverting the two decorators:
             pass
 """
         raise CannotDecorateClassmethods(msg)
-        
 
     all_args = get_all_arg_names(function_)
 
@@ -245,8 +209,8 @@ you can achieve the same goal by inverting the two decorators:
             if function_.__doc__ is None:
                 # XXX: change name
                 raise ContractException(
-                                'You did not specify a contract, nor I can '
-                                        'find a docstring for %r.' % function_)
+                    'You did not specify a contract, nor I can '
+                    'find a docstring for %r.' % function_)
 
             accepts_dict, returns = parse_contracts_from_docstring(function_)
 
@@ -259,10 +223,10 @@ you can achieve the same goal by inverting the two decorators:
         returns_parsed = parse_flexible_spec(returns)
 
     accepts_parsed = dict([(x, parse_flexible_spec(accepts_dict[x]))
-                            for x in accepts_dict])
+                           for x in accepts_dict])
 
     is_bound_method = 'self' in all_args
-    
+
     def contracts_checker(unused, *args, **kwargs):
         do_checks = not all_disabled()
         if not do_checks:
@@ -272,26 +236,25 @@ you can achieve the same goal by inverting the two decorators:
             nice_function_display = '%s()' % function_.__name__
             if is_bound_method:
                 klass = type(args[0]).__name__
-                nice_function_display = klass + ':' + nice_function_display  
+                nice_function_display = klass + ':' + nice_function_display
             return nice_function_display
-        
+
         bound = getcallargs(function_, *args, **kwargs)
 
-        try:
-            context = {}
-            # add self if we are a bound method
-            if is_bound_method:
-                context['self'] = args[0]
+        context = {}
+        # add self if we are a bound method
+        if is_bound_method:
+            context['self'] = args[0]
 
-            for arg in all_args:
-                if arg in accepts_parsed:
+        for arg in all_args:
+            if arg in accepts_parsed:
+                try:
                     accepts_parsed[arg]._check_contract(context, bound[arg])
-
-        except ContractNotRespected as e:
-            msg = ('Breach for argument %r to %s.\n'
-                   % (arg, get_nice_function_display()))
-            e.error = msg + e.error
-            raise e
+                except ContractNotRespected as e:
+                    msg = ('Breach for argument %r to %s.\n'
+                           % (arg, get_nice_function_display()))
+                    e.error = msg + e.error
+                    raise e
 
         result = function_(*args, **kwargs)
 
@@ -318,7 +281,7 @@ you can achieve the same goal by inverting the two decorators:
             docs = DocStringInfo("")
         for param in accepts_parsed:
             if not param in docs.params:
-#                default = '*not documented*'
+                # default = '*not documented*'
                 default = ''
                 docs.params[param] = Arg(default, None)
 
@@ -340,6 +303,7 @@ you can achieve the same goal by inverting the two decorators:
 
     # TODO: is using functools.wraps better?
     from decorator import decorator
+
     wrapper = decorator(contracts_checker, function_)
 
     wrapper.__doc__ = new_docs
@@ -351,14 +315,15 @@ you can achieve the same goal by inverting the two decorators:
 
 
 def parse_flexible_spec(spec):
-    ''' spec can be either a Contract, a type, or a contract string. 
-        In the latter case, the usual parsing takes place'''
+    """ spec can be either a Contract, a type, or a contract string.
+        In the latter case, the usual parsing takes place"""
     if isinstance(spec, Contract):
         return spec
     elif isinstance(spec, str):
         return parse_contract_string(spec)
     elif can_be_used_as_a_type(spec):
         from .library import CheckType
+
         return CheckType(spec)
     else:
         raise ContractException('I want either a string or a type, not %s.'
@@ -372,7 +337,7 @@ def parse_contracts_from_docstring(function):
         raise ContractException('More than one return type specified.')
 
     def remove_quotes(x):
-        ''' Removes the double back-tick quotes if present. '''
+        """ Removes the double back-tick quotes if present. """
         if x is None:
             return None
         if x.startswith('``') and x.endswith('``') and len(x) > 3:
@@ -391,13 +356,13 @@ def parse_contracts_from_docstring(function):
     # These are the annotations
     params = annotations.params
     name2type = dict([(name, remove_quotes(params[name].type))
-                       for name in params])
+                      for name in params])
 
     # Check the ones that do not have contracts specified
     nullparams = [name for name in params if params[name].type is None]
     if nullparams:
         msg = ('The parameter(s) %r in this docstring have no type statement.'
-                % (",".join(nullparams)))
+               % (",".join(nullparams)))
         msg += """
 
 Note: you can use the asterisk if you do not care about assigning
@@ -415,8 +380,8 @@ a contract to a certain parameter:
     for name in name2type:
         if not name in all_args:
             msg = ('A contract was specified for argument %r which I cannot'
-                   ' find in my list of arguments (%r)' % 
-                    (name, all_args))
+                   ' find in my list of arguments (%r)' %
+                   (name, all_args))
             raise ContractException(msg)
 
     if len(name2type) != len(all_args):  # pragma: no cover
@@ -425,6 +390,7 @@ a contract to a certain parameter:
 
     return name2type, returns
 
+
 inPy3k = sys.version_info[0] == 3
 
 
@@ -440,20 +406,20 @@ def get_all_arg_names(function):
 
 
 def check(contract, object, desc=None, **context):  # @ReservedAssignment
-    ''' 
-        Checks that ``object`` satisfies the contract 
+    """
+        Checks that ``object`` satisfies the contract
         described by ``contract``.
-    
+
         :param contract: The contract string.
         :type contract:  str
-        
+
         :param object: Any object.
         :type object: ``*``
 
-        :param desc: An optional description of the error. If given, 
+        :param desc: An optional description of the error. If given,
                      it is included in the error message.
         :type desc: ``None|str``
-    '''
+    """
     if all_disabled():
         return {}
 
@@ -470,11 +436,11 @@ def check(contract, object, desc=None, **context):  # @ReservedAssignment
 
 
 def fail(contract, value, **initial_context):
-    ''' Checks that the value **does not** respect this contract.
-        Raises an exception if it does. 
-       
-       :raise: ValueError 
-    '''
+    """ Checks that the value **does not** respect this contract.
+        Raises an exception if it does.
+
+       :raise: ValueError
+    """
     try:
         parsed_contract = parse_contract_string(contract)
         context = check_contracts([contract], [value], initial_context)
@@ -489,19 +455,19 @@ def fail(contract, value, **initial_context):
 
 
 def check_multiple(couples, desc=None):
-    ''' 
-        Checks multiple couples of (contract, value) in the same context. 
-        
-        This means that the variables in each contract are shared with 
-        the others. 
-        
+    """
+        Checks multiple couples of (contract, value) in the same context.
+
+        This means that the variables in each contract are shared with
+        the others.
+
         :param couples: A list of tuple (contract, value) to check.
         :type couples: ``list[>0](tuple(str, *))``
-        
-        :param desc: An optional description of the error. If given, 
+
+        :param desc: An optional description of the error. If given,
                      it is included in the error message.
         :type desc: ``None|str``
-    '''
+    """
 
     check('list[>0](tuple(str, *))', couples,
           'I expect a non-empty list of (object, string) tuples.')
@@ -516,53 +482,53 @@ def check_multiple(couples, desc=None):
 
 
 def new_contract(*args):
-    ''' Defines a new contract type. Used both as a decorator and as 
+    """ Defines a new contract type. Used both as a decorator and as
         a function.
-    
-        **1) Use as a function.** The first parameter must be a string. 
+
+        **1) Use as a function.** The first parameter must be a string.
         The second parameter can be either
         a string or a callable function.  ::
-        
-            new_contract('new_contract_name', 'list[N]') 
+
+            new_contract('new_contract_name', 'list[N]')
             new_contract('new_contract_name', lambda x: isinstance(x, list) )
-            
-        - If it is a string, it is interpreted as contract expression; 
+
+        - If it is a string, it is interpreted as contract expression;
           the given identifier will become an alias
-          for that expression. 
-          
+          for that expression.
+
         - If it is a callable, it must accept one parameter, and either:
-          
+
           * return True or None, to signify it accepts.
-          
-          * return False or raise ValueError or AssertionError, 
+
+          * return False or raise ValueError or AssertionError,
             to signify it doesn't.
-          
+
           If ValueError is raised, its message is used in the error.
 
         **2) Use as a decorator.**
 
         Or, it can be used as a decorator (without arguments).
         The function name is used as the identifier. ::
-        
+
             @new_contract
             def new_contract_name(x):
                 return isinstance(x, list)
-        
-          
+
+
         This function returns a :py:class:`Contract` object. It might be
         useful to check right away if the declaration is what you meant,
-        using :py:func:`Contract.check` and :py:func:`Contract.fail`.  
-        
+        using :py:func:`Contract.check` and :py:func:`Contract.fail`.
+
         :param identifier: The identifier must be a string not already in use
                           (you cannot redefine ``list``, ``tuple``, etc.).
-        :type identifier: str 
-        
+        :type identifier: str
+
         :param condition: Definition of the new contract.
         :type condition: ``type|callable|str``
-        
+
         :return: The equivalent contract -- might be useful for debugging.
         :rtype: Contract
-    '''
+    """
     if args and len(args) == 1 and isinstance(args[0], types.FunctionType):
         # TODO: add here for class decorator
         # We were called without parameters
@@ -578,11 +544,11 @@ def new_contract_impl(identifier, condition):
     # Be friendly
     if not isinstance(identifier, str):
         raise ValueError('I expect the identifier to be a string; '
-                         'received %s.' % 
+                         'received %s.' %
                          describe_value(identifier))
 
     # Make sure it is not already an expression that we know.
-    #  (exception: allow redundant definitions. To this purpose,
+    # (exception: allow redundant definitions. To this purpose,
     #   skip this test if the identifier is already known, and catch
     #   later if the condition changed.)
     if identifier in Extension.registrar:
@@ -594,21 +560,23 @@ def new_contract_impl(identifier, condition):
         try:
             c = parse_contract_string(identifier)
             msg = ('Invalid identifier %r; it overwrites an already known '
-                   'expression. In fact, I can parse it as %s (%r).' % 
-                             (identifier, c, c))
+                   'expression. In fact, I can parse it as %s (%r).' %
+                   (identifier, c, c))
             raise ValueError(msg)
         except ContractSyntaxError:
             pass
 
     # Make sure it corresponds to our idea of identifier
     try:
-        c = identifier_expression.parseString(identifier, parseAll=True)  # @UndefinedVariable
+        c = identifier_expression.parseString(identifier,
+                                              parseAll=True)  #
+                                              # @UndefinedVariable
     except ParseException as e:
         where = Where(identifier, line=e.lineno, column=e.col)
         # msg = 'Error in parsing string: %s' % e 
         msg = ('The given identifier %r does not correspond to my idea '
                'of what an identifier should look like;\n%s\n%s'
-                 % (identifier, e, where))
+               % (identifier, e, where))
         raise ValueError(msg)
 
     # Now let's check the condition
@@ -618,7 +586,7 @@ def new_contract_impl(identifier, condition):
             # could call parse_flexible_spec as well here
             bare_contract = parse_contract_string(condition)
         except ContractSyntaxError as e:
-            msg = ('The given condition %r does not parse cleanly: %s' % 
+            msg = ('The given condition %r does not parse cleanly: %s' %
                    (condition, e))
             raise ValueError(msg)
     # Important: types are callable, so check this first.
@@ -634,7 +602,7 @@ def new_contract_impl(identifier, condition):
             can, error = can_accept_exactly_one_argument(condition)
             if not can:
                 msg = ('The given callable %r should be able to accept '
-                      'exactly one argument. Error: %s ' % (condition, error))
+                       'exactly one argument. Error: %s ' % (condition, error))
                 raise ValueError(msg)
             bare_contract = CheckCallable(condition)
     else:
@@ -650,7 +618,7 @@ def new_contract_impl(identifier, condition):
     # It's okay if we define the same thing twice
     if identifier in Extension.registrar:
         old = Extension.registrar[identifier]
-        if not(contract == old):
+        if not (contract == old):
             msg = ('Tried to redefine %r with a definition that looks '
                    'different to me.\n' % identifier)
             msg += ' - old: %r\n' % old
@@ -664,12 +632,13 @@ def new_contract_impl(identifier, condition):
         c = parse_contract_string(identifier)
         expected = Extension(identifier)
         assert c == expected, \
-              'Expected %r, got %r.' % (c, expected)  # pragma: no cover
+            'Expected %r, got %r.' % (c, expected)  # pragma: no cover
     except ContractSyntaxError as e:  # pragma: no cover
         assert False, 'Cannot parse %r: %s' % (identifier, e)
 
     return contract
-#    return bare_contract
+
+# return bare_contract
 #    return condition
 
 
@@ -679,10 +648,10 @@ if inPy2:
 
 
 def can_be_used_as_a_type(x):
-    ''' Checks that x can be used as a type; specifically,
-        we can write isintance(y,x). 
-        Here we support old-style classes. 
-    '''
+    """ Checks that x can be used as a type; specifically,
+        we can write isintance(y,x).
+        Here we support old-style classes.
+    """
     if isinstance(x, type):
         return True
 
@@ -694,9 +663,9 @@ def can_be_used_as_a_type(x):
 
 
 def can_accept_exactly_one_argument(callable_thing):
-    ''' Checks that a callable can accept exactly one argument
+    """ Checks that a callable can accept exactly one argument
         using introspection.
-    '''
+    """
     if inspect.ismethod(callable_thing):  # bound method
         f = callable_thing.__func__
         args = (callable_thing.__self__, 'test',)
@@ -717,9 +686,9 @@ def can_accept_exactly_one_argument(callable_thing):
 
 
 def can_accept_self_plus_one_argument(callable_thing):
-    ''' Checks that a callable can accept exactly self plus one argument
+    """ Checks that a callable can accept exactly self plus one argument
         using introspection.
-    '''
+    """
 
     if inspect.ismethod(callable_thing):  # bound method
         f = callable_thing.__func__
@@ -740,6 +709,5 @@ def can_accept_self_plus_one_argument(callable_thing):
     else:
         return True
 
-    return False
 
 
