@@ -68,8 +68,8 @@ def test_reconversion():
 
 
 def check_good_repr(c):
-    ''' Checks that we can eval() the __repr__() value and we get
-        an equivalent object. '''
+    """ Checks that we can eval() the __repr__() value and we get
+        an equivalent object. """
     parsed = parse_contract_string(c)
     # Check that it compares true with itself
     assert parsed.__eq__(parsed), 'Repr does not know itself: %r' % parsed
@@ -87,8 +87,8 @@ def check_good_repr(c):
 
 
 def check_recoversion(s, exact):
-    ''' Checks that we can eval() the __repr__() value and we get
-        an equivalent object. '''
+    """ Checks that we can eval() the __repr__() value and we get
+        an equivalent object. """
     parsed = parse_contract_string(s)
 
     s2 = parsed.__str__()
